@@ -1,7 +1,3 @@
-try:
-    from simplejson import dumps, loads
-except ImportError:  # pragma: no cover
-    from json import dumps, loads  # noqa
 from inspect import Arguments
 from itertools import chain, tee
 from mimetypes import guess_type, add_type
@@ -18,6 +14,7 @@ from webob import (Request as WebObRequest, Response as WebObResponse, exc,
 from webob.multidict import NestedMultiDict
 
 from .compat import urlparse, izip
+from .jsonify import encode as dumps
 from .secure import handle_security
 from .templating import RendererFactory
 from .routing import lookup_controller, NonCanonicalPath
@@ -668,6 +665,9 @@ class PecanBase(object):
         }
         controller = None
 
+        # track internal redirects
+        internal_redirect = False
+
         # handle the request
         try:
             # add context and environment to the request
@@ -697,9 +697,12 @@ class PecanBase(object):
                     state.response.content_type = best_match
                 environ['pecan.original_exception'] = e
 
+            # note if this is an internal redirect
+            internal_redirect = isinstance(e, ForwardRequestException)
+
             # if this is not an internal redirect, run error hooks
             on_error_result = None
-            if not isinstance(e, ForwardRequestException):
+            if not internal_redirect:
                 on_error_result = self.handle_hooks(
                     self.determine_hooks(state.controller),
                     'on_error',
@@ -720,10 +723,13 @@ class PecanBase(object):
                 if allowed_methods:
                     state.response.allow = sorted(allowed_methods)
         finally:
-            # handle "after" hooks
-            self.handle_hooks(
-                self.determine_hooks(state.controller), 'after', state
-            )
+            # if this is not an internal redirect, run "after" hooks
+            if not internal_redirect:
+                self.handle_hooks(
+                    self.determine_hooks(state.controller),
+                    'after',
+                    state
+                )
 
         self._handle_empty_response_body(state)
 
